Skip to contents

Read the event store into a flat data frame of action rows

Usage

plog_read(dir = getOption("scdbayes.log_dir"))

Arguments

dir

Log directory; defaults to getOption("scdbayes.log_dir").

Value

A data frame with t, session, action, target — or NULL if empty.