Provides a Bayesian multilevel modeling workflow for single-case experimental designs via 'brms' and 'Stan'. Includes piecewise regression with random effects, posterior-based effect sizes, cross-case consistency estimates, support for AB, reversal, multiple baseline, multiple probe, alternating treatment, and changing criterion designs, 2- to 4+ level hierarchical structures for single-study and meta-analytic data, and an interactive 'Shiny' interface for data upload, model specification, diagnostics, and export of reproducible scripts and reports.
Author
Maintainer: Mikyung Shin shin.mikyung@gmail.com (ORCID)
Authors:
Mikyung Shin shin.mikyung@gmail.com (ORCID)