Read the event store into a flat data frame of action rows
Source:R/utils-process-log.R
plog_read.RdRead the event store into a flat data frame of action rows
Usage
plog_read(dir = getOption("scdbayes.log_dir"))
R/utils-process-log.R
plog_read.RdRead the event store into a flat data frame of action rows
plog_read(dir = getOption("scdbayes.log_dir"))